@@ -136,6 +136,28 @@ transparent_type_abbrev(int trans_type)
 }
 
 
+const char *
+x_visual_type_abbrev(int x_visual_type)
+{
+    switch (x_visual_type) {
+       case GLX_TRUE_COLOR:
+           return "tc";
+       case GLX_DIRECT_COLOR:
+           return "dc";
+       case GLX_PSEUDO_COLOR:
+           return "pc";
+       case GLX_STATIC_COLOR:
+           return "sc";
+       case GLX_GRAY_SCALE:
+           return "gs";
+       case GLX_STATIC_GRAY:
+           return "sg";
+       default:
+           return ".";
+    }
+}
+
+
 const char *
 caveat_abbrev(int caveat)
 {
@@ -160,23 +182,24 @@ print_fbconfig_attribs(GLXFBConfigAttr *fbca)
         return;
     }
 
-    printf("-fc- -vi- buf lv rgb d s colorbuffer ax dp st "
-           "accumbuffer -ms- cav -----pbuffer----- ---transparent----\n");
-    printf(" id   id  siz l  ci  b t r  g  b  a  bf th en "
-           "r  g  b  a  ns b eat widt hght max-pxs typ r  g  b  a  i\n");
-    printf("----------------------------------------------"
-           "---------------------------------------------------------\n");
+    printf("--fc- -vi- vt buf lv rgb d s colorbuffer ax dp st "
+           "accumbuffer ---ms---- cav -----pbuffer----- ---transparent----\n");
+    printf("  id   id     siz l  ci  b t  r  g  b  a bf th en "
+           " r  g  b  a mvs mcs b eat widt hght max-pxs typ  r  g  b  a  i\n");
+    printf("--------------------------------------------------"
+           "--------------------------------------------------------------\n");
 
     i = 0;
     while ( fbca[i].fbconfig_id != 0 ) {
         
-        printf("0x%2.2x ", fbca[i].fbconfig_id);
+        printf("0x%03x ", fbca[i].fbconfig_id);
         if ( fbca[i].visual_id ) {
             printf("0x%2.2x ", fbca[i].visual_id);
         } else {
             printf("   . ");
         }
-        printf("%3d %2d %3.3s %1c %1c ",
+        printf("%2.2s %3d %2d %3.3s %1c %1c ",
+               x_visual_type_abbrev(fbca[i].x_visual_type),
                fbca[i].buffer_size,
                fbca[i].level,
                render_type_abbrev(fbca[i].render_type),
@@ -199,12 +222,25 @@ print_fbconfig_attribs(GLXFBConfigAttr *fbca)
                fbca[i].accum_alpha_size
                );
         if ( fbca[i].multi_sample_valid == 1 ) {
-            printf("%2d %1d ",
-                   fbca[i].multi_samples,
+            printf("%3d ",
+                   fbca[i].multi_samples
+                   );
+
+            if ( fbca[i].multi_sample_coverage_valid == 1 ) {
+                printf("%3d ",
+                       fbca[i].multi_samples_color
+                       );
+            } else {
+                printf("%3d ",
+                       fbca[i].multi_samples
+                       );
+            }
+            printf("%1d ",
                    fbca[i].multi_sample_buffers
                    );
+
         } else {
-            printf(" . . ");
+            printf("  .   . . ");
         }
         printf("%3.3s %4x %4x %7x %3.3s %2d %2d %2d %2d %2d\n",
                caveat_abbrev(fbca[i].config_caveat),
@@ -247,6 +283,7 @@ void print_glxinfo(const char *display_name)
 {
     int              screen;
     CtrlHandles     *h;
+    CtrlHandleTarget *t;
     ReturnStatus     status = NvCtrlSuccess;
 
     char            *direct_rendering  = NULL;
@@ -266,27 +303,28 @@ void print_glxinfo(const char *display_name)
 
     char            *formated_ext_str  = NULL;
 
-
     h = nv_alloc_ctrl_handles(display_name);
     if ( h == NULL ) {
         return;
     }
 
     /* Print information for each screen */
-    for (screen = 0; screen < h->num_screens; screen++) {
+    for (screen = 0; screen < h->targets[X_SCREEN_TARGET].n; screen++) {
+
+        t = &h->targets[X_SCREEN_TARGET].t[screen];
 
         /* No screen, move on */
-        if ( !h->h[screen] ) continue;
+        if ( !t->h ) continue;
 
-        nv_msg(NULL, "GLX Information for %s:", h->screen_names[screen]);
+        nv_msg(NULL, "GLX Information for %s:", t->name);
 
         /* Get GLX information */
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_DIRECT_RENDERING,
                                           &direct_rendering);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_GLX_EXTENSIONS,
                                           &glx_extensions);
         if ( status != NvCtrlSuccess &&
@@ -299,17 +337,17 @@ void print_glxinfo(const char *display_name)
             }
         }
         /* Get server GLX information */
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_SERVER_VENDOR,
                                           &server_vendor);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_SERVER_VERSION,
                                           &server_version);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_SERVER_EXTENSIONS,
                                           &server_extensions);
         if ( status != NvCtrlSuccess &&
@@ -322,17 +360,17 @@ void print_glxinfo(const char *display_name)
             }
         }
         /* Get client GLX information */
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_CLIENT_VENDOR,
                                           &client_vendor);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_CLIENT_VERSION,
                                           &client_version);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_CLIENT_EXTENSIONS,
                                           &client_extensions);
         if ( status != NvCtrlSuccess &&
@@ -345,22 +383,22 @@ void print_glxinfo(const char *display_name)
             }
         }
         /* Get OpenGL information */
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_OPENGL_VENDOR,
                                           &opengl_vendor);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_OPENGL_RENDERER,
                                           &opengl_renderer);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_OPENGL_VERSION,
                                           &opengl_version);
         if ( status != NvCtrlSuccess &&
              status != NvCtrlNoAttribute ) { goto finish; }
-        status = NvCtrlGetStringAttribute(h->h[screen],
+        status = NvCtrlGetStringAttribute(t->h,
                                           NV_CTRL_STRING_GLX_OPENGL_EXTENSIONS,
                                           &opengl_extensions);
         if ( status != NvCtrlSuccess &&
@@ -374,7 +412,7 @@ void print_glxinfo(const char *display_name)
         }
 
         /* Get FBConfig information */
-        status = NvCtrlGetVoidAttribute(h->h[screen],
+        status = NvCtrlGetVoidAttribute(t->h,
                                         NV_CTRL_ATTR_GLX_FBCONFIG_ATTRIBS,
                                         (void *)(&fbconfig_attribs));
         if ( status != NvCtrlSuccess &&
